Convenience wrapper around add_effects that keeps only positive
effects, that is, rows with benefit > 0.
Arguments
- x
A
Problemobject created withcreate_problem. It must already contain feasible actions; runadd_actionsfirst.- benefits
Alias of
effects, kept for backwards compatibility.- effect_type
Character string indicating how supplied effect values are interpreted. Must be one of:
"delta": values represent signed net changes,"after": values represent after-action amounts and are converted to net changes relative to baseline feature amounts.
- effect_aggregation
Character string giving the aggregation used when converting raster values to planning-unit level. Must be one of
"sum"or"mean".
Value
An updated Problem object containing:
dist_effectsThe canonical filtered effects table, containing only rows with
benefit > 0.dist_benefitA backwards-compatible mirror table containing only the benefit component.