Add locked planning units to a problem
Source:R/add_constraint_locked_planning_units.R
add_constraint_locked_pu.Rdadd_constraint_locked_pu() has been replaced by
add_constraint_locked_planning_units.
Arguments
- x
A
Problemobject created withcreate_problem.- locked_in
Optional locked-in specification. It may be
NULL, a column name in the raw planning-unit data, a logical vector, or a vector of planning-unit ids.- locked_out
Optional locked-out specification. It may be
NULL, a column name in the raw planning-unit data, a logical vector, or a vector of planning-unit ids.
Value
An updated Problem object in which the planning-unit table
contains logical columns locked_in and locked_out.