Convenience wrapper around add_effects that keeps only negative
effects, represented by rows with loss > 0.
Arguments
- x
A
Problemobject created withcreate_problem. It must already contain feasible actions; runadd_actionsfirst.- losses
Alias of
effects, used for symmetry withadd_benefits().- effect_type
Character string indicating how supplied effect values are interpreted. Must be one of:
"delta": values represent signed net changes,"after": values represent after-action amounts and are converted to net changes relative to baseline feature amounts.
- effect_aggregation
Character string giving the aggregation used when converting raster values to planning-unit level. Must be one of
"sum"or"mean".
Value
An updated Problem object containing:
dist_effectsThe canonical filtered effects table, containing only rows with
loss > 0.dist_lossA convenience table containing only the loss component.
losses_metaMetadata for the stored loss table.