A compact example dataset containing all inputs needed to build a multi-objective spatial planning problem with protection and restoration as mutually exclusive candidate actions.
Usage
data(sim_multiaction)Format
A named list with six components:
planning_unitsAn
sfobject with 64 square planning units.featuresA data frame with two feature identifiers and names.
dist_featuresA data frame of feature amounts by planning unit.
actionsA data frame describing protection and restoration.
action_costsA data frame of spatially varying action costs.
effectsA data frame of action-specific feature multipliers.